package silastang.camera_flash;

import android.app.Activity;
import android.hardware.camera2.CameraAccessException;
import android.util.Log;

import androidx.annotation.NonNull;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugins.camera.CameraPermissions;
import io.flutter.plugins.camera.DartMessenger;
import io.flutter.plugins.camera.MethodCallHandlerImpl;
import io.flutter.view.TextureRegistry;

final class FlashMethodCallHandlerImpl extends MethodCallHandlerImpl {

    public FlashMethodCallHandlerImpl(
            Activity activity,
            BinaryMessenger messenger,
            CameraPermissions cameraPermissions,
            CameraPermissions.PermissionsRegistry permissionsAdder,
            TextureRegistry textureRegistry) {
        super(activity, messenger, cameraPermissions, permissionsAdder, textureRegistry);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull final MethodChannel.Result result) {
        if (call.method.equals("turnOnFlash")) {
           try {
               Log.i("", "turning on flash");
               ((CameraFlash)camera).toggleFlashMode(true);
               result.success(null);
           } catch (Exception e) {
               handleException(e, result);
           }
       } else if (call.method.equals("turnOffFlash")) {
           try {
               Log.i("", "turning off flash");
               ((CameraFlash)camera).toggleFlashMode(false);
               result.success(null);
           } catch (Exception e) {
               handleException(e, result);
           }
       } else {
            super.onMethodCall(call, result);
        }
    }

    @Override
    public void instantiateCamera(MethodCall call, MethodChannel.Result result) throws CameraAccessException {
        String cameraName = call.argument("cameraName");
        String resolutionPreset = call.argument("resolutionPreset");
        boolean enableAudio = call.argument("enableAudio");
        TextureRegistry.SurfaceTextureEntry flutterSurfaceTexture =
                textureRegistry.createSurfaceTexture();
        DartMessenger dartMessenger = new DartMessenger(messenger, flutterSurfaceTexture.id());
        camera =
                new CameraFlash(
                        activity,
                        flutterSurfaceTexture,
                        dartMessenger,
                        cameraName,
                        resolutionPreset,
                        enableAudio);

        camera.open(result);
    }


}
