import 'dart:async';
import 'package:flutter/material.dart';
import 'package:camera/camera.dart';
import 'package:camera_flash/flash_camera_controller.dart';

class MessageCameraScreen extends StatefulWidget {
  final CameraDescription camera;

  const MessageCameraScreen({Key key, this.camera}) : super(key: key);

  @override
  MessageCameraScreenState createState() => MessageCameraScreenState();
}

class MessageCameraScreenState extends State<MessageCameraScreen> {
  FlashCameraController _controller;
  Future<void> _initializeControllerFuture;
  bool _isFlashOn = false;

  @override
  void initState() {
    super.initState();
    _controller = FlashCameraController(
      widget.camera,
      ResolutionPreset.high,
    );
    _initializeControllerFuture = _controller.initialize();

  }


  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final screenWidth = MediaQuery.of(context).size.width;
    return Scaffold(
      body: FutureBuilder<void>(
        future: _initializeControllerFuture,
        builder: (context, snapshot) {
          if (snapshot.connectionState == ConnectionState.done) {
            return Stack(
              children: <Widget>[
                CameraPreview(_controller),
                Positioned(
                  top: screenWidth / 17 + 10,
                  left: screenWidth / 17,
                  child: IconButton(
                    onPressed: () => Navigator.pop(context),
                    icon: Icon(Icons.close, color: Colors.white, size: screenWidth / 12.5),
                  ),
                ),
                Positioned(
                  top: screenWidth / 17 + 10,
                  right: screenWidth / 17,
                  child: IconButton(
                    onPressed: () async {
                      print(_isFlashOn);
                      if (_isFlashOn) {
                        await _controller.turnOffFlash();
                      } else {
                        await _controller.turnOnFlash();
                      }
                      _isFlashOn = !_isFlashOn;
                    },
                    icon: Icon(Icons.flash_on, color: Colors.white, size: screenWidth / 12.5),
                  ),
                ),
                Positioned(
                  bottom: screenWidth / 17 + 10,
                  left: screenWidth / 17,
                  child: IconButton(
                    onPressed: () {},
                    icon: Icon(Icons.photo, color: Colors.white, size: screenWidth / 12.5),
                  ),
                ),
//                     Align(
//                       alignment: Alignment.bottomCenter,
//                       child: Container(
//                           margin: EdgeInsets.only(bottom: screenWidth / 17 + 10),
//                           width: screenWidth / 3,
//                           child: AxlGradientButton(title: 'Capture',
//                             onPressed: () async {
//                               try {
//                                 await _initializeControllerFuture;
//                                 final path = join(
//                                   (await getTemporaryDirectory()).path,
//                                   '${DateTime.now()}.png',
//                                 );
//
//                                 await _controller.takePicture(path);
//
//                                 // If the picture was taken, display it on a new screen with path
//
//                               } catch (e) {
//                                 print(e);
//                               }
//                             },
//                           )),
//                     )
              ],
            );
          }
          return Center(child: CircularProgressIndicator());
        },
      ),
    );
  }

}